package com.macgyverski.titankeyboard;

import android.content.ClipData;
import android.content.ClipboardManager;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.graphics.Typeface;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.appcompat.app.AppCompatActivity;

import java.util.Date;

public class ClipboardActivity extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.clipboard_activity);
        ImageView imageView=(ImageView)findViewById(R.id.removeClipboard);
        imageView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                SharedPreferences sharedPref = getSharedPreferences("clipBoardContent", MODE_PRIVATE);
                SharedPreferences.Editor editor = sharedPref.edit();
                String dateCleared = String.format("%tc", new Date());
                editor.putString("clipBoardContent", (String) "Clipboard cleared on " + dateCleared + " !");
                editor.commit();
            }
        });

        ImageView clipImageView=(ImageView)findViewById(R.id.clippy);
        clipImageView.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                Intent intent = new Intent (ClipboardActivity.this, MainActivity.class);
                startActivity(intent);
            }
        });

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            getWindow().setStatusBarColor(getResources().getColor(R.color.teal_700, this.getTheme()));
        } else if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            getWindow().setStatusBarColor(getResources().getColor(R.color.teal_700));
        }

        SharedPreferences sharedPref = getSharedPreferences("clipBoardContent", MODE_PRIVATE);
        String clipboardSavedData = sharedPref.getString("clipBoardContent", null);

        if(TextUtils.isEmpty(clipboardSavedData)){
            clipboardSavedData = "Empty clipboard;separator;Copy data first";
        }

        ViewGroup container = (ViewGroup) findViewById(R.id.main_grid);
        // `this` would be your activity/application context so it has correct theme info
        LayoutInflater inflater = LayoutInflater.from(this);

        String[] separated = clipboardSavedData.split(";separator;");
        int clipbaordSize = clipboardSavedData.split(";separator;").length;

        TextView[] myTextViews = new TextView[clipbaordSize];
        for (int i = 0; i < clipbaordSize; i++) {
            boolean isFirst = false;
            if (i == 0) {isFirst = true;}
            TextView textView = createNewTextViewWithText(separated[i], isFirst);

            ViewGroup.LayoutParams params = new ViewGroup.LayoutParams(
                    ViewGroup.LayoutParams.MATCH_PARENT,
                    ViewGroup.LayoutParams.WRAP_CONTENT
            );
            container.addView(textView, params);
            myTextViews[i] = textView;
        }
    }

    private TextView createNewTextViewWithText(String text, boolean isActive) {
        // I prefer inflating the TextView, as it's easier to
        // specify layout params in XML, IMO
        TextView textView = new TextView(this);
        textView.setText(text);
        textView.setTextSize(16);
        if (isActive == true) {
            textView.setTypeface(null, Typeface.BOLD);
            textView.setTextSize(24);
        }
        textView.setPadding(0,0,0,50);
        textView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                ClipboardManager clipboard = (ClipboardManager) getSystemService(Context.CLIPBOARD_SERVICE);
                ClipData clip = ClipData.newPlainText("Copied With Clipboard Manager", text);
                clipboard.setPrimaryClip(clip);
            }
        });
        return textView;
    }

}