package com.macgyverski.titankeyboard;

import static androidx.core.app.ActivityCompat.startActivityForResult;

import android.content.ClipData;
import android.content.ClipboardManager;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.inputmethodservice.InputMethodService;
import android.inputmethodservice.Keyboard;
import android.inputmethodservice.KeyboardView;
import android.media.AudioManager;
import android.os.Vibrator;
import android.text.TextUtils;
import android.view.KeyEvent;
import android.view.View;
import android.view.inputmethod.InputConnection;

public class MyInputMethodService extends InputMethodService implements KeyboardView.OnKeyboardActionListener
{

    public MyInputMethodService() {
        super();
    }

    private KeyboardView keyboardView;
    private Keyboard keyboard;

    private boolean caps = false;

    @Override
    public View onCreateInputView() {
        keyboardView = (KeyboardView) getLayoutInflater().inflate(R.layout.keyboard_view, null);
        keyboard = new Keyboard(this, R.xml.qwerty);
        keyboardView.setKeyboard(keyboard);
        keyboardView.setOnKeyboardActionListener(this);
        return keyboardView;
    }

    @Override
    public void onPress(int primaryCode) {
        Vibrator vibe = (Vibrator) getSystemService(Context.VIBRATOR_SERVICE);
        vibe.vibrate(50);
        AudioManager am = (AudioManager)getSystemService(Context.AUDIO_SERVICE);
        am.playSoundEffect(AudioManager.FX_KEY_CLICK, 1);
    }

    @Override
    public void onRelease(int primaryCode) {

    }

    @Override
    public void onKey(int primaryCode, int[] keyCodes) {
        InputConnection inputConnection = getCurrentInputConnection();

        if (inputConnection != null) {
            switch(primaryCode) {

                case  Keyboard.KEYCODE_DELETE:
                    CharSequence selectedText = inputConnection.getSelectedText(0);

                    if (TextUtils.isEmpty(selectedText)) {
                        inputConnection.deleteSurroundingText(1, 0);
                    } else {
                        inputConnection.commitText("", 1);
                    }
                    break;
                case Keyboard.KEYCODE_SHIFT:
                    keyboard = new Keyboard(this, R.xml.qwerty);
                    keyboardView.setKeyboard(keyboard);
                    caps = !caps;
                    keyboard.setShifted(caps);
                    keyboardView.invalidateAllKeys();
                    break;
                case Keyboard.KEYCODE_MODE_CHANGE:
                    keyboard = new Keyboard(this, R.xml.keys_layout);
                    keyboardView.setKeyboard(keyboard);
                    break;
                case -10:
                    keyboard = new Keyboard(this, R.xml.more_keys_layout);
                    keyboardView.setKeyboard(keyboard);
                    break;
                case -11:
                    keyboard = new Keyboard(this, R.xml.keys_layout);
                    keyboardView.setKeyboard(keyboard);
                    break;
                case 10:
                    keyboard = new Keyboard(this, R.xml.keys_layout);
                    inputConnection.sendKeyEvent(new KeyEvent(KeyEvent.ACTION_DOWN, KeyEvent.KEYCODE_ENTER));
                    break;
                case 37:
                    inputConnection.sendKeyEvent(new KeyEvent(KeyEvent.ACTION_DOWN, KeyEvent.KEYCODE_DPAD_LEFT));
                    inputConnection.sendKeyEvent(new KeyEvent(KeyEvent.ACTION_UP, KeyEvent.KEYCODE_DPAD_LEFT));
                    break;
                case 38:
                    inputConnection.sendKeyEvent(new KeyEvent(KeyEvent.ACTION_DOWN, KeyEvent.KEYCODE_DPAD_UP));
                    inputConnection.sendKeyEvent(new KeyEvent(KeyEvent.ACTION_UP, KeyEvent.KEYCODE_DPAD_UP));
                    break;
                case 39:
                    inputConnection.sendKeyEvent(new KeyEvent(KeyEvent.ACTION_DOWN, KeyEvent.KEYCODE_DPAD_RIGHT));
                    inputConnection.sendKeyEvent(new KeyEvent(KeyEvent.ACTION_UP, KeyEvent.KEYCODE_DPAD_RIGHT));
                    break;
                case 40:
                    inputConnection.sendKeyEvent(new KeyEvent(KeyEvent.ACTION_DOWN, KeyEvent.KEYCODE_DPAD_DOWN));
                    inputConnection.sendKeyEvent(new KeyEvent(KeyEvent.ACTION_UP, KeyEvent.KEYCODE_DPAD_DOWN));
                    break;
                case -31:
                    CharSequence textToCopy = inputConnection.getSelectedText(0);
                    ClipboardManager clipboard = (ClipboardManager) getSystemService(Context.CLIPBOARD_SERVICE);
                    ClipData clip = ClipData.newPlainText("Copied with MacGyverski keyboard", textToCopy);
                    clipboard.setPrimaryClip(clip);

                    SharedPreferences sharedPref = getSharedPreferences("clipBoardContent", MODE_PRIVATE);
                    String clipboardSavedData = sharedPref.getString("clipBoardContent", null);

                    SharedPreferences.Editor editor = sharedPref.edit();
                    editor.putString("clipBoardContent", (String) textToCopy + ";separator;" + clipboardSavedData);
                    editor.commit();
                    break;
                case -32:
                    ClipboardManager clipboardd = (ClipboardManager) getSystemService(CLIPBOARD_SERVICE);
                    CharSequence clipboardText = clipboardd.getText();
                    inputConnection.commitText(clipboardText, 1);
                    break;
                case -33:
                    keyboard = new Keyboard(this, R.xml.emoji);
                    keyboardView.setKeyboard(keyboard);
                    break;
                case -34:
                    inputConnection.commitText("\ud83e\udd13", 1);
                    //nerd
                    break;
                case -35:
                    inputConnection.commitText("\ud83e\udd20", 1);
                    //cowboy
                    break;
                case -36:
                    inputConnection.commitText("\ud83d\ude0d", 1);
                    //hearteyes 0xD83D 0xDE0D
                    break;
                case -37:
                    inputConnection.commitText("\ud83c\udf7a", 1);
                    //beer 0xD83C 0xDF7A
                    break;
                case -38:
                    inputConnection.commitText("\ud83d\udc4d", 1);
                    //likeit 0xD83D 0xDC4D
                    break;
                case -39:
                    inputConnection.commitText("\ud83c\udf55", 1);
                    //pizza 0xD83C 0xDF55
                    break;
                case -40:
                    inputConnection.commitText("\ud83d\ude00", 1);
                    //smile 0xD83D 0xDE00
                    break;
                case -41:
                    final Intent intent = new Intent(Intent.ACTION_MAIN, null);
                    final ComponentName cn = new ComponentName(
                            "com.macgyverski.titankeyboard",
                            "com.macgyverski.titankeyboard.ClipboardActivity");
                    intent.setComponent(cn);
                    intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                    startActivity(intent);
                    break;
                case -42:
                    keyboard = new Keyboard(this, R.xml.navigation);
                    keyboardView.setKeyboard(keyboard);
                    break;
                case Keyboard.KEYCODE_DONE:
                    inputConnection.sendKeyEvent(new KeyEvent(KeyEvent.ACTION_DOWN, KeyEvent.KEYCODE_ENTER));
                    break;
                default :
                    char code = (char) primaryCode;
                    if(Character.isLetter(code) && caps){
                        code = Character.toUpperCase(code);
                    }
                    inputConnection.commitText(String.valueOf(code), 1);

            }
        }

    }

    @Override
    public void onText(CharSequence text) {

    }

    @Override
    public void swipeLeft() {

    }

    @Override
    public void swipeRight() {

    }

    @Override
    public void swipeDown() {

    }

    @Override
    public void swipeUp() {

    }
}
